==> openshift-model-operatorhub-6.9.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/UpdateStrategyFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class UpdateStrategyFluent<A extends UpdateStrategyFluent<A>> extends BaseFluent<A>{
  public UpdateStrategyFluent() {
  }
  
  public UpdateStrategyFluent(UpdateStrategy instance) {
    this.copyInstance(instance);
  }
  private RegistryPollBuilder registryPoll;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(UpdateStrategy instance) {
    instance = (instance != null ? instance : new UpdateStrategy());
    if (instance != null) {
          this.withRegistryPoll(instance.getRegistryPoll());
          this.withRegistryPoll(instance.getRegistryPoll());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public RegistryPoll buildRegistryPoll() {
    return this.registryPoll != null ? this.registryPoll.build() : null;
  }
  
  public A withRegistryPoll(RegistryPoll registryPoll) {
    this._visitables.remove(this.registryPoll);
    if (registryPoll != null) {
        this.registryPoll = new RegistryPollBuilder(registryPoll);
        this._visitables.get("registryPoll").add(this.registryPoll);
    } else {
        this.registryPoll = null;
        this._visitables.get("registryPoll").remove(this.registryPoll);
    }
    return (A) this;
  }
  
  public boolean hasRegistryPoll() {
    return this.registryPoll != null;
  }
  
  public A withNewRegistryPoll(String interval) {
    return (A)withRegistryPoll(new RegistryPoll(interval));
  }
  
  public RegistryPollNested<A> withNewRegistryPoll() {
    return new RegistryPollNested(null);
  }
  
  public RegistryPollNested<A> withNewRegistryPollLike(RegistryPoll item) {
    return new RegistryPollNested(item);
  }
  
  public RegistryPollNested<A> editRegistryPoll() {
    return withNewRegistryPollLike(java.util.Optional.ofNullable(buildRegistryPoll()).orElse(null));
  }
  
  public RegistryPollNested<A> editOrNewRegistryPoll() {
    return withNewRegistryPollLike(java.util.Optional.ofNullable(buildRegistryPoll()).orElse(new RegistryPollBuilder().build()));
  }
  
  public RegistryPollNested<A> editOrNewRegistryPollLike(RegistryPoll item) {
    return withNewRegistryPollLike(java.util.Optional.ofNullable(buildRegistryPoll()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    UpdateStrategyFluent that = (UpdateStrategyFluent) o;
    if (!java.util.Objects.equals(registryPoll, that.registryPoll)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(registryPoll,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (registryPoll != null) { sb.append("registryPoll:"); sb.append(registryPoll + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class RegistryPollNested<N> extends RegistryPollFluent<RegistryPollNested<N>> implements Nested<N>{
    RegistryPollNested(RegistryPoll item) {
      this.builder = new RegistryPollBuilder(this, item);
    }
    RegistryPollBuilder builder;
    
    public N and() {
      return (N) UpdateStrategyFluent.this.withRegistryPoll(builder.build());
    }
    
    public N endRegistryPoll() {
      return and();
    }
    
  
  }

}

==> openshift-model-operatorhub-6.13.4-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/UpdateStrategyFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class UpdateStrategyFluent<A extends UpdateStrategyFluent<A>> extends BaseFluent<A>{
  public UpdateStrategyFluent() {
  }
  
  public UpdateStrategyFluent(UpdateStrategy instance) {
    this.copyInstance(instance);
  }
  private RegistryPollBuilder registryPoll;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(UpdateStrategy instance) {
    instance = (instance != null ? instance : new UpdateStrategy());
    if (instance != null) {
          this.withRegistryPoll(instance.getRegistryPoll());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public RegistryPoll buildRegistryPoll() {
    return this.registryPoll != null ? this.registryPoll.build() : null;
  }
  
  public A withRegistryPoll(RegistryPoll registryPoll) {
    this._visitables.remove("registryPoll");
    if (registryPoll != null) {
        this.registryPoll = new RegistryPollBuilder(registryPoll);
        this._visitables.get("registryPoll").add(this.registryPoll);
    } else {
        this.registryPoll = null;
        this._visitables.get("registryPoll").remove(this.registryPoll);
    }
    return (A) this;
  }
  
  public boolean hasRegistryPoll() {
    return this.registryPoll != null;
  }
  
  public A withNewRegistryPoll(String interval) {
    return (A)withRegistryPoll(new RegistryPoll(interval));
  }
  
  public RegistryPollNested<A> withNewRegistryPoll() {
    return new RegistryPollNested(null);
  }
  
  public RegistryPollNested<A> withNewRegistryPollLike(RegistryPoll item) {
    return new RegistryPollNested(item);
  }
  
  public RegistryPollNested<A> editRegistryPoll() {
    return withNewRegistryPollLike(java.util.Optional.ofNullable(buildRegistryPoll()).orElse(null));
  }
  
  public RegistryPollNested<A> editOrNewRegistryPoll() {
    return withNewRegistryPollLike(java.util.Optional.ofNullable(buildRegistryPoll()).orElse(new RegistryPollBuilder().build()));
  }
  
  public RegistryPollNested<A> editOrNewRegistryPollLike(RegistryPoll item) {
    return withNewRegistryPollLike(java.util.Optional.ofNullable(buildRegistryPoll()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    UpdateStrategyFluent that = (UpdateStrategyFluent) o;
    if (!java.util.Objects.equals(registryPoll, that.registryPoll)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(registryPoll,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (registryPoll != null) { sb.append("registryPoll:"); sb.append(registryPoll + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class RegistryPollNested<N> extends RegistryPollFluent<RegistryPollNested<N>> implements Nested<N>{
    RegistryPollNested(RegistryPoll item) {
      this.builder = new RegistryPollBuilder(this, item);
    }
    RegistryPollBuilder builder;
    
    public N and() {
      return (N) UpdateStrategyFluent.this.withRegistryPoll(builder.build());
    }
    
    public N endRegistryPoll() {
      return and();
    }
    
  
  }

}
